# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spec.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='spec.proto',
  package='gauge.messages',
  syntax='proto3',
  serialized_pb=_b('\n\nspec.proto\x12\x0egauge.messages\"\x9d\x03\n\tProtoSpec\x12\x13\n\x0bspecHeading\x18\x01 \x01(\t\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.gauge.messages.ProtoItem\x12\x15\n\risTableDriven\x18\x03 \x01(\x08\x12\x39\n\x0fpreHookFailures\x18\x04 \x03(\x0b\x32 .gauge.messages.ProtoHookFailure\x12:\n\x10postHookFailures\x18\x05 \x03(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x10\n\x08\x66ileName\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x17\n\x0fpreHookMessages\x18\x08 \x03(\t\x12\x18\n\x10postHookMessages\x18\t \x03(\t\x12\x1a\n\x0epreHookMessage\x18\n \x03(\tB\x02\x18\x01\x12\x1b\n\x0fpostHookMessage\x18\x0b \x03(\tB\x02\x18\x01\x12\x1a\n\x12preHookScreenshots\x18\x0c \x03(\x0c\x12\x1b\n\x13postHookScreenshots\x18\r \x03(\x0c\"\x80\x04\n\tProtoItem\x12\x34\n\x08itemType\x18\x01 \x01(\x0e\x32\".gauge.messages.ProtoItem.ItemType\x12\'\n\x04step\x18\x02 \x01(\x0b\x32\x19.gauge.messages.ProtoStep\x12-\n\x07\x63oncept\x18\x03 \x01(\x0b\x32\x1c.gauge.messages.ProtoConcept\x12/\n\x08scenario\x18\x04 \x01(\x0b\x32\x1d.gauge.messages.ProtoScenario\x12\x45\n\x13tableDrivenScenario\x18\x05 \x01(\x0b\x32(.gauge.messages.ProtoTableDrivenScenario\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.gauge.messages.ProtoComment\x12)\n\x05table\x18\x07 \x01(\x0b\x32\x1a.gauge.messages.ProtoTable\x12\'\n\x04tags\x18\x08 \x01(\x0b\x32\x19.gauge.messages.ProtoTags\"j\n\x08ItemType\x12\x08\n\x04Step\x10\x00\x12\x0b\n\x07\x43omment\x10\x01\x12\x0b\n\x07\x43oncept\x10\x02\x12\x0c\n\x08Scenario\x10\x03\x12\x17\n\x13TableDrivenScenario\x10\x04\x12\t\n\x05Table\x10\x05\x12\x08\n\x04Tags\x10\x06\"\x9f\x05\n\rProtoScenario\x12\x17\n\x0fscenarioHeading\x18\x01 \x01(\t\x12\x12\n\x06\x66\x61iled\x18\x02 \x01(\x08\x42\x02\x18\x01\x12+\n\x08\x63ontexts\x18\x03 \x03(\x0b\x32\x19.gauge.messages.ProtoItem\x12\x30\n\rscenarioItems\x18\x04 \x03(\x0b\x32\x19.gauge.messages.ProtoItem\x12\x38\n\x0epreHookFailure\x18\x05 \x01(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x39\n\x0fpostHookFailure\x18\x06 \x01(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x15\n\rexecutionTime\x18\x08 \x01(\x03\x12\x13\n\x07skipped\x18\t \x01(\x08\x42\x02\x18\x01\x12\x12\n\nskipErrors\x18\n \x03(\t\x12\n\n\x02ID\x18\x0b \x01(\t\x12\x30\n\rtearDownSteps\x18\x0c \x03(\x0b\x32\x19.gauge.messages.ProtoItem\x12\"\n\x04span\x18\r \x01(\x0b\x32\x14.gauge.messages.Span\x12\x38\n\x0f\x65xecutionStatus\x18\x0e \x01(\x0e\x32\x1f.gauge.messages.ExecutionStatus\x12\x17\n\x0fpreHookMessages\x18\x0f \x03(\t\x12\x18\n\x10postHookMessages\x18\x10 \x03(\t\x12\x1a\n\x0epreHookMessage\x18\x11 \x03(\tB\x02\x18\x01\x12\x1b\n\x0fpostHookMessage\x18\x12 \x03(\tB\x02\x18\x01\x12\x1a\n\x12preHookScreenshots\x18\x13 \x03(\x0c\x12\x1b\n\x13postHookScreenshots\x18\x14 \x03(\x0c\"F\n\x04Span\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\x12\x11\n\tstartChar\x18\x03 \x01(\x03\x12\x0f\n\x07\x65ndChar\x18\x04 \x01(\x03\"b\n\x18ProtoTableDrivenScenario\x12/\n\x08scenario\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ProtoScenario\x12\x15\n\rtableRowIndex\x18\x02 \x01(\x05\"\x93\x02\n\tProtoStep\x12\x12\n\nactualText\x18\x01 \x01(\t\x12\x12\n\nparsedText\x18\x02 \x01(\t\x12+\n\tfragments\x18\x03 \x03(\x0b\x32\x18.gauge.messages.Fragment\x12\x45\n\x13stepExecutionResult\x18\x04 \x01(\x0b\x32(.gauge.messages.ProtoStepExecutionResult\x12\x17\n\x0fpreHookMessages\x18\x05 \x03(\t\x12\x18\n\x10postHookMessages\x18\x06 \x03(\t\x12\x1a\n\x12preHookScreenshots\x18\x07 \x03(\x0c\x12\x1b\n\x13postHookScreenshots\x18\x08 \x03(\x0c\"\xb2\x01\n\x0cProtoConcept\x12.\n\x0b\x63onceptStep\x18\x01 \x01(\x0b\x32\x19.gauge.messages.ProtoStep\x12(\n\x05steps\x18\x02 \x03(\x0b\x32\x19.gauge.messages.ProtoItem\x12H\n\x16\x63onceptExecutionResult\x18\x03 \x01(\x0b\x32(.gauge.messages.ProtoStepExecutionResult\"\x19\n\tProtoTags\x12\x0c\n\x04tags\x18\x01 \x03(\t\"\xac\x01\n\x08\x46ragment\x12;\n\x0c\x66ragmentType\x18\x01 \x01(\x0e\x32%.gauge.messages.Fragment.FragmentType\x12\x0c\n\x04text\x18\x02 \x01(\t\x12,\n\tparameter\x18\x03 \x01(\x0b\x32\x19.gauge.messages.Parameter\"\'\n\x0c\x46ragmentType\x12\x08\n\x04Text\x10\x00\x12\r\n\tParameter\x10\x01\"\xef\x01\n\tParameter\x12>\n\rparameterType\x18\x01 \x01(\x0e\x32\'.gauge.messages.Parameter.ParameterType\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12)\n\x05table\x18\x04 \x01(\x0b\x32\x1a.gauge.messages.ProtoTable\"Z\n\rParameterType\x12\n\n\x06Static\x10\x00\x12\x0b\n\x07\x44ynamic\x10\x01\x12\x12\n\x0eSpecial_String\x10\x02\x12\x11\n\rSpecial_Table\x10\x03\x12\t\n\x05Table\x10\x04\"\x1c\n\x0cProtoComment\x12\x0c\n\x04text\x18\x01 \x01(\t\"i\n\nProtoTable\x12.\n\x07headers\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ProtoTableRow\x12+\n\x04rows\x18\x02 \x03(\x0b\x32\x1d.gauge.messages.ProtoTableRow\"\x1e\n\rProtoTableRow\x12\r\n\x05\x63\x65lls\x18\x01 \x03(\t\"\xf6\x01\n\x18ProtoStepExecutionResult\x12=\n\x0f\x65xecutionResult\x18\x01 \x01(\x0b\x32$.gauge.messages.ProtoExecutionResult\x12\x38\n\x0epreHookFailure\x18\x02 \x01(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x39\n\x0fpostHookFailure\x18\x03 \x01(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x0f\n\x07skipped\x18\x04 \x01(\x08\x12\x15\n\rskippedReason\x18\x05 \x01(\t\"\xcb\x02\n\x14ProtoExecutionResult\x12\x0e\n\x06\x66\x61iled\x18\x01 \x01(\x08\x12\x18\n\x10recoverableError\x18\x02 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x12\n\nstackTrace\x18\x04 \x01(\t\x12\x16\n\nscreenShot\x18\x05 \x01(\x0c\x42\x02\x18\x01\x12\x15\n\rexecutionTime\x18\x06 \x01(\x03\x12\x0f\n\x07message\x18\x07 \x03(\t\x12\x41\n\terrorType\x18\x08 \x01(\x0e\x32..gauge.messages.ProtoExecutionResult.ErrorType\x12\x19\n\x11\x66\x61ilureScreenshot\x18\t \x01(\x0c\x12\x13\n\x0bscreenshots\x18\n \x03(\x0c\",\n\tErrorType\x12\r\n\tASSERTION\x10\x00\x12\x10\n\x0cVERIFICATION\x10\x01\"\x86\x01\n\x10ProtoHookFailure\x12\x12\n\nstackTrace\x18\x01 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x16\n\nscreenShot\x18\x03 \x01(\x0c\x42\x02\x18\x01\x12\x15\n\rtableRowIndex\x18\x04 \x01(\x05\x12\x19\n\x11\x66\x61ilureScreenshot\x18\x05 \x01(\x0c\"\x9e\x04\n\x10ProtoSuiteResult\x12\x34\n\x0bspecResults\x18\x01 \x03(\x0b\x32\x1f.gauge.messages.ProtoSpecResult\x12\x38\n\x0epreHookFailure\x18\x02 \x01(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x39\n\x0fpostHookFailure\x18\x03 \x01(\x0b\x32 .gauge.messages.ProtoHookFailure\x12\x0e\n\x06\x66\x61iled\x18\x04 \x01(\x08\x12\x18\n\x10specsFailedCount\x18\x05 \x01(\x05\x12\x15\n\rexecutionTime\x18\x06 \x01(\x03\x12\x13\n\x0bsuccessRate\x18\x07 \x01(\x02\x12\x13\n\x0b\x65nvironment\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\t \x01(\t\x12\x13\n\x0bprojectName\x18\n \x01(\t\x12\x11\n\ttimestamp\x18\x0b \x01(\t\x12\x19\n\x11specsSkippedCount\x18\x0c \x01(\x05\x12\x17\n\x0fpreHookMessages\x18\r \x03(\t\x12\x18\n\x10postHookMessages\x18\x0e \x03(\t\x12\x1a\n\x0epreHookMessage\x18\x0f \x03(\tB\x02\x18\x01\x12\x1b\n\x0fpostHookMessage\x18\x10 \x03(\tB\x02\x18\x01\x12\x1a\n\x12preHookScreenshots\x18\x11 \x03(\x0c\x12\x1b\n\x13postHookScreenshots\x18\x12 \x03(\x0c\"\xab\x02\n\x0fProtoSpecResult\x12,\n\tprotoSpec\x18\x01 \x01(\x0b\x32\x19.gauge.messages.ProtoSpec\x12\x15\n\rscenarioCount\x18\x02 \x01(\x05\x12\x1b\n\x13scenarioFailedCount\x18\x03 \x01(\x05\x12\x0e\n\x06\x66\x61iled\x18\x04 \x01(\x08\x12\x1b\n\x13\x66\x61iledDataTableRows\x18\x05 \x03(\x05\x12\x15\n\rexecutionTime\x18\x06 \x01(\x03\x12\x0f\n\x07skipped\x18\x07 \x01(\x08\x12\x1c\n\x14scenarioSkippedCount\x18\x08 \x01(\x05\x12\x1c\n\x14skippedDataTableRows\x18\t \x03(\x05\x12%\n\x06\x65rrors\x18\n \x03(\x0b\x32\x15.gauge.messages.Error\"\xa1\x01\n\x05\x45rror\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.gauge.messages.Error.ErrorType\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x12\n\nlineNumber\x18\x03 \x01(\x05\x12\x0f\n\x07message\x18\x04 \x01(\t\"2\n\tErrorType\x12\x0f\n\x0bPARSE_ERROR\x10\x00\x12\x14\n\x10VALIDATION_ERROR\x10\x01\"W\n\x0eProtoStepValue\x12\x11\n\tstepValue\x18\x01 \x01(\t\x12\x1e\n\x16parameterizedStepValue\x18\x02 \x01(\t\x12\x12\n\nparameters\x18\x03 \x03(\t*G\n\x0f\x45xecutionStatus\x12\x0f\n\x0bNOTEXECUTED\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0b\n\x07SKIPPED\x10\x03\x42)\n\x16\x63om.thoughtworks.gauge\xaa\x02\x0eGauge.Messagesb\x06proto3')
)

_EXECUTIONSTATUS = _descriptor.EnumDescriptor(
  name='ExecutionStatus',
  full_name='gauge.messages.ExecutionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOTEXECUTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PASSED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4699,
  serialized_end=4770,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONSTATUS)

ExecutionStatus = enum_type_wrapper.EnumTypeWrapper(_EXECUTIONSTATUS)
NOTEXECUTED = 0
PASSED = 1
FAILED = 2
SKIPPED = 3


_PROTOITEM_ITEMTYPE = _descriptor.EnumDescriptor(
  name='ItemType',
  full_name='gauge.messages.ProtoItem.ItemType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Step', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Comment', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Concept', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Scenario', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableDrivenScenario', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Table', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Tags', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=853,
  serialized_end=959,
)
_sym_db.RegisterEnumDescriptor(_PROTOITEM_ITEMTYPE)

_FRAGMENT_FRAGMENTTYPE = _descriptor.EnumDescriptor(
  name='FragmentType',
  full_name='gauge.messages.Fragment.FragmentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Text', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Parameter', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2427,
  serialized_end=2466,
)
_sym_db.RegisterEnumDescriptor(_FRAGMENT_FRAGMENTTYPE)

_PARAMETER_PARAMETERTYPE = _descriptor.EnumDescriptor(
  name='ParameterType',
  full_name='gauge.messages.Parameter.ParameterType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Static', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Dynamic', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Special_String', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Special_Table', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Table', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2618,
  serialized_end=2708,
)
_sym_db.RegisterEnumDescriptor(_PARAMETER_PARAMETERTYPE)

_PROTOEXECUTIONRESULT_ERRORTYPE = _descriptor.EnumDescriptor(
  name='ErrorType',
  full_name='gauge.messages.ProtoExecutionResult.ErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASSERTION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFICATION', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3416,
  serialized_end=3460,
)
_sym_db.RegisterEnumDescriptor(_PROTOEXECUTIONRESULT_ERRORTYPE)

_ERROR_ERRORTYPE = _descriptor.EnumDescriptor(
  name='ErrorType',
  full_name='gauge.messages.Error.ErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARSE_ERROR', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATION_ERROR', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4558,
  serialized_end=4608,
)
_sym_db.RegisterEnumDescriptor(_ERROR_ERRORTYPE)


_PROTOSPEC = _descriptor.Descriptor(
  name='ProtoSpec',
  full_name='gauge.messages.ProtoSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specHeading', full_name='gauge.messages.ProtoSpec.specHeading', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='gauge.messages.ProtoSpec.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isTableDriven', full_name='gauge.messages.ProtoSpec.isTableDriven', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookFailures', full_name='gauge.messages.ProtoSpec.preHookFailures', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookFailures', full_name='gauge.messages.ProtoSpec.postHookFailures', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='gauge.messages.ProtoSpec.fileName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.ProtoSpec.tags', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessages', full_name='gauge.messages.ProtoSpec.preHookMessages', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessages', full_name='gauge.messages.ProtoSpec.postHookMessages', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessage', full_name='gauge.messages.ProtoSpec.preHookMessage', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessage', full_name='gauge.messages.ProtoSpec.postHookMessage', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookScreenshots', full_name='gauge.messages.ProtoSpec.preHookScreenshots', index=11,
      number=12, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookScreenshots', full_name='gauge.messages.ProtoSpec.postHookScreenshots', index=12,
      number=13, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=444,
)


_PROTOITEM = _descriptor.Descriptor(
  name='ProtoItem',
  full_name='gauge.messages.ProtoItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='itemType', full_name='gauge.messages.ProtoItem.itemType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step', full_name='gauge.messages.ProtoItem.step', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept', full_name='gauge.messages.ProtoItem.concept', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenario', full_name='gauge.messages.ProtoItem.scenario', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableDrivenScenario', full_name='gauge.messages.ProtoItem.tableDrivenScenario', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='gauge.messages.ProtoItem.comment', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='gauge.messages.ProtoItem.table', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.ProtoItem.tags', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROTOITEM_ITEMTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=959,
)


_PROTOSCENARIO = _descriptor.Descriptor(
  name='ProtoScenario',
  full_name='gauge.messages.ProtoScenario',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scenarioHeading', full_name='gauge.messages.ProtoScenario.scenarioHeading', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failed', full_name='gauge.messages.ProtoScenario.failed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contexts', full_name='gauge.messages.ProtoScenario.contexts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioItems', full_name='gauge.messages.ProtoScenario.scenarioItems', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookFailure', full_name='gauge.messages.ProtoScenario.preHookFailure', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookFailure', full_name='gauge.messages.ProtoScenario.postHookFailure', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.ProtoScenario.tags', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionTime', full_name='gauge.messages.ProtoScenario.executionTime', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skipped', full_name='gauge.messages.ProtoScenario.skipped', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skipErrors', full_name='gauge.messages.ProtoScenario.skipErrors', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ID', full_name='gauge.messages.ProtoScenario.ID', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tearDownSteps', full_name='gauge.messages.ProtoScenario.tearDownSteps', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span', full_name='gauge.messages.ProtoScenario.span', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionStatus', full_name='gauge.messages.ProtoScenario.executionStatus', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessages', full_name='gauge.messages.ProtoScenario.preHookMessages', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessages', full_name='gauge.messages.ProtoScenario.postHookMessages', index=15,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessage', full_name='gauge.messages.ProtoScenario.preHookMessage', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessage', full_name='gauge.messages.ProtoScenario.postHookMessage', index=17,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookScreenshots', full_name='gauge.messages.ProtoScenario.preHookScreenshots', index=18,
      number=19, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookScreenshots', full_name='gauge.messages.ProtoScenario.postHookScreenshots', index=19,
      number=20, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1633,
)


_SPAN = _descriptor.Descriptor(
  name='Span',
  full_name='gauge.messages.Span',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='gauge.messages.Span.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='gauge.messages.Span.end', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startChar', full_name='gauge.messages.Span.startChar', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endChar', full_name='gauge.messages.Span.endChar', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1635,
  serialized_end=1705,
)


_PROTOTABLEDRIVENSCENARIO = _descriptor.Descriptor(
  name='ProtoTableDrivenScenario',
  full_name='gauge.messages.ProtoTableDrivenScenario',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scenario', full_name='gauge.messages.ProtoTableDrivenScenario.scenario', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableRowIndex', full_name='gauge.messages.ProtoTableDrivenScenario.tableRowIndex', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1707,
  serialized_end=1805,
)


_PROTOSTEP = _descriptor.Descriptor(
  name='ProtoStep',
  full_name='gauge.messages.ProtoStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actualText', full_name='gauge.messages.ProtoStep.actualText', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parsedText', full_name='gauge.messages.ProtoStep.parsedText', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fragments', full_name='gauge.messages.ProtoStep.fragments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepExecutionResult', full_name='gauge.messages.ProtoStep.stepExecutionResult', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessages', full_name='gauge.messages.ProtoStep.preHookMessages', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessages', full_name='gauge.messages.ProtoStep.postHookMessages', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookScreenshots', full_name='gauge.messages.ProtoStep.preHookScreenshots', index=6,
      number=7, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookScreenshots', full_name='gauge.messages.ProtoStep.postHookScreenshots', index=7,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1808,
  serialized_end=2083,
)


_PROTOCONCEPT = _descriptor.Descriptor(
  name='ProtoConcept',
  full_name='gauge.messages.ProtoConcept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conceptStep', full_name='gauge.messages.ProtoConcept.conceptStep', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steps', full_name='gauge.messages.ProtoConcept.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conceptExecutionResult', full_name='gauge.messages.ProtoConcept.conceptExecutionResult', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2264,
)


_PROTOTAGS = _descriptor.Descriptor(
  name='ProtoTags',
  full_name='gauge.messages.ProtoTags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.ProtoTags.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2266,
  serialized_end=2291,
)


_FRAGMENT = _descriptor.Descriptor(
  name='Fragment',
  full_name='gauge.messages.Fragment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fragmentType', full_name='gauge.messages.Fragment.fragmentType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='gauge.messages.Fragment.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='gauge.messages.Fragment.parameter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FRAGMENT_FRAGMENTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2294,
  serialized_end=2466,
)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='gauge.messages.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameterType', full_name='gauge.messages.Parameter.parameterType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='gauge.messages.Parameter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='gauge.messages.Parameter.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='gauge.messages.Parameter.table', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARAMETER_PARAMETERTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2469,
  serialized_end=2708,
)


_PROTOCOMMENT = _descriptor.Descriptor(
  name='ProtoComment',
  full_name='gauge.messages.ProtoComment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='gauge.messages.ProtoComment.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2710,
  serialized_end=2738,
)


_PROTOTABLE = _descriptor.Descriptor(
  name='ProtoTable',
  full_name='gauge.messages.ProtoTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='gauge.messages.ProtoTable.headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows', full_name='gauge.messages.ProtoTable.rows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2740,
  serialized_end=2845,
)


_PROTOTABLEROW = _descriptor.Descriptor(
  name='ProtoTableRow',
  full_name='gauge.messages.ProtoTableRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cells', full_name='gauge.messages.ProtoTableRow.cells', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2847,
  serialized_end=2877,
)


_PROTOSTEPEXECUTIONRESULT = _descriptor.Descriptor(
  name='ProtoStepExecutionResult',
  full_name='gauge.messages.ProtoStepExecutionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionResult', full_name='gauge.messages.ProtoStepExecutionResult.executionResult', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookFailure', full_name='gauge.messages.ProtoStepExecutionResult.preHookFailure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookFailure', full_name='gauge.messages.ProtoStepExecutionResult.postHookFailure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skipped', full_name='gauge.messages.ProtoStepExecutionResult.skipped', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skippedReason', full_name='gauge.messages.ProtoStepExecutionResult.skippedReason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2880,
  serialized_end=3126,
)


_PROTOEXECUTIONRESULT = _descriptor.Descriptor(
  name='ProtoExecutionResult',
  full_name='gauge.messages.ProtoExecutionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='failed', full_name='gauge.messages.ProtoExecutionResult.failed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recoverableError', full_name='gauge.messages.ProtoExecutionResult.recoverableError', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='gauge.messages.ProtoExecutionResult.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stackTrace', full_name='gauge.messages.ProtoExecutionResult.stackTrace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='screenShot', full_name='gauge.messages.ProtoExecutionResult.screenShot', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionTime', full_name='gauge.messages.ProtoExecutionResult.executionTime', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='gauge.messages.ProtoExecutionResult.message', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorType', full_name='gauge.messages.ProtoExecutionResult.errorType', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureScreenshot', full_name='gauge.messages.ProtoExecutionResult.failureScreenshot', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='screenshots', full_name='gauge.messages.ProtoExecutionResult.screenshots', index=9,
      number=10, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROTOEXECUTIONRESULT_ERRORTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3129,
  serialized_end=3460,
)


_PROTOHOOKFAILURE = _descriptor.Descriptor(
  name='ProtoHookFailure',
  full_name='gauge.messages.ProtoHookFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stackTrace', full_name='gauge.messages.ProtoHookFailure.stackTrace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='gauge.messages.ProtoHookFailure.errorMessage', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='screenShot', full_name='gauge.messages.ProtoHookFailure.screenShot', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableRowIndex', full_name='gauge.messages.ProtoHookFailure.tableRowIndex', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureScreenshot', full_name='gauge.messages.ProtoHookFailure.failureScreenshot', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3463,
  serialized_end=3597,
)


_PROTOSUITERESULT = _descriptor.Descriptor(
  name='ProtoSuiteResult',
  full_name='gauge.messages.ProtoSuiteResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specResults', full_name='gauge.messages.ProtoSuiteResult.specResults', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookFailure', full_name='gauge.messages.ProtoSuiteResult.preHookFailure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookFailure', full_name='gauge.messages.ProtoSuiteResult.postHookFailure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failed', full_name='gauge.messages.ProtoSuiteResult.failed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specsFailedCount', full_name='gauge.messages.ProtoSuiteResult.specsFailedCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionTime', full_name='gauge.messages.ProtoSuiteResult.executionTime', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='successRate', full_name='gauge.messages.ProtoSuiteResult.successRate', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='environment', full_name='gauge.messages.ProtoSuiteResult.environment', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.ProtoSuiteResult.tags', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='projectName', full_name='gauge.messages.ProtoSuiteResult.projectName', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gauge.messages.ProtoSuiteResult.timestamp', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specsSkippedCount', full_name='gauge.messages.ProtoSuiteResult.specsSkippedCount', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessages', full_name='gauge.messages.ProtoSuiteResult.preHookMessages', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessages', full_name='gauge.messages.ProtoSuiteResult.postHookMessages', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookMessage', full_name='gauge.messages.ProtoSuiteResult.preHookMessage', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookMessage', full_name='gauge.messages.ProtoSuiteResult.postHookMessage', index=15,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preHookScreenshots', full_name='gauge.messages.ProtoSuiteResult.preHookScreenshots', index=16,
      number=17, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postHookScreenshots', full_name='gauge.messages.ProtoSuiteResult.postHookScreenshots', index=17,
      number=18, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3600,
  serialized_end=4142,
)


_PROTOSPECRESULT = _descriptor.Descriptor(
  name='ProtoSpecResult',
  full_name='gauge.messages.ProtoSpecResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protoSpec', full_name='gauge.messages.ProtoSpecResult.protoSpec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioCount', full_name='gauge.messages.ProtoSpecResult.scenarioCount', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioFailedCount', full_name='gauge.messages.ProtoSpecResult.scenarioFailedCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failed', full_name='gauge.messages.ProtoSpecResult.failed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failedDataTableRows', full_name='gauge.messages.ProtoSpecResult.failedDataTableRows', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionTime', full_name='gauge.messages.ProtoSpecResult.executionTime', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skipped', full_name='gauge.messages.ProtoSpecResult.skipped', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioSkippedCount', full_name='gauge.messages.ProtoSpecResult.scenarioSkippedCount', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skippedDataTableRows', full_name='gauge.messages.ProtoSpecResult.skippedDataTableRows', index=8,
      number=9, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors', full_name='gauge.messages.ProtoSpecResult.errors', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4145,
  serialized_end=4444,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='gauge.messages.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='gauge.messages.Error.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='gauge.messages.Error.filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lineNumber', full_name='gauge.messages.Error.lineNumber', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='gauge.messages.Error.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERROR_ERRORTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4447,
  serialized_end=4608,
)


_PROTOSTEPVALUE = _descriptor.Descriptor(
  name='ProtoStepValue',
  full_name='gauge.messages.ProtoStepValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepValue', full_name='gauge.messages.ProtoStepValue.stepValue', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterizedStepValue', full_name='gauge.messages.ProtoStepValue.parameterizedStepValue', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='gauge.messages.ProtoStepValue.parameters', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4610,
  serialized_end=4697,
)

_PROTOSPEC.fields_by_name['items'].message_type = _PROTOITEM
_PROTOSPEC.fields_by_name['preHookFailures'].message_type = _PROTOHOOKFAILURE
_PROTOSPEC.fields_by_name['postHookFailures'].message_type = _PROTOHOOKFAILURE
_PROTOITEM.fields_by_name['itemType'].enum_type = _PROTOITEM_ITEMTYPE
_PROTOITEM.fields_by_name['step'].message_type = _PROTOSTEP
_PROTOITEM.fields_by_name['concept'].message_type = _PROTOCONCEPT
_PROTOITEM.fields_by_name['scenario'].message_type = _PROTOSCENARIO
_PROTOITEM.fields_by_name['tableDrivenScenario'].message_type = _PROTOTABLEDRIVENSCENARIO
_PROTOITEM.fields_by_name['comment'].message_type = _PROTOCOMMENT
_PROTOITEM.fields_by_name['table'].message_type = _PROTOTABLE
_PROTOITEM.fields_by_name['tags'].message_type = _PROTOTAGS
_PROTOITEM_ITEMTYPE.containing_type = _PROTOITEM
_PROTOSCENARIO.fields_by_name['contexts'].message_type = _PROTOITEM
_PROTOSCENARIO.fields_by_name['scenarioItems'].message_type = _PROTOITEM
_PROTOSCENARIO.fields_by_name['preHookFailure'].message_type = _PROTOHOOKFAILURE
_PROTOSCENARIO.fields_by_name['postHookFailure'].message_type = _PROTOHOOKFAILURE
_PROTOSCENARIO.fields_by_name['tearDownSteps'].message_type = _PROTOITEM
_PROTOSCENARIO.fields_by_name['span'].message_type = _SPAN
_PROTOSCENARIO.fields_by_name['executionStatus'].enum_type = _EXECUTIONSTATUS
_PROTOTABLEDRIVENSCENARIO.fields_by_name['scenario'].message_type = _PROTOSCENARIO
_PROTOSTEP.fields_by_name['fragments'].message_type = _FRAGMENT
_PROTOSTEP.fields_by_name['stepExecutionResult'].message_type = _PROTOSTEPEXECUTIONRESULT
_PROTOCONCEPT.fields_by_name['conceptStep'].message_type = _PROTOSTEP
_PROTOCONCEPT.fields_by_name['steps'].message_type = _PROTOITEM
_PROTOCONCEPT.fields_by_name['conceptExecutionResult'].message_type = _PROTOSTEPEXECUTIONRESULT
_FRAGMENT.fields_by_name['fragmentType'].enum_type = _FRAGMENT_FRAGMENTTYPE
_FRAGMENT.fields_by_name['parameter'].message_type = _PARAMETER
_FRAGMENT_FRAGMENTTYPE.containing_type = _FRAGMENT
_PARAMETER.fields_by_name['parameterType'].enum_type = _PARAMETER_PARAMETERTYPE
_PARAMETER.fields_by_name['table'].message_type = _PROTOTABLE
_PARAMETER_PARAMETERTYPE.containing_type = _PARAMETER
_PROTOTABLE.fields_by_name['headers'].message_type = _PROTOTABLEROW
_PROTOTABLE.fields_by_name['rows'].message_type = _PROTOTABLEROW
_PROTOSTEPEXECUTIONRESULT.fields_by_name['executionResult'].message_type = _PROTOEXECUTIONRESULT
_PROTOSTEPEXECUTIONRESULT.fields_by_name['preHookFailure'].message_type = _PROTOHOOKFAILURE
_PROTOSTEPEXECUTIONRESULT.fields_by_name['postHookFailure'].message_type = _PROTOHOOKFAILURE
_PROTOEXECUTIONRESULT.fields_by_name['errorType'].enum_type = _PROTOEXECUTIONRESULT_ERRORTYPE
_PROTOEXECUTIONRESULT_ERRORTYPE.containing_type = _PROTOEXECUTIONRESULT
_PROTOSUITERESULT.fields_by_name['specResults'].message_type = _PROTOSPECRESULT
_PROTOSUITERESULT.fields_by_name['preHookFailure'].message_type = _PROTOHOOKFAILURE
_PROTOSUITERESULT.fields_by_name['postHookFailure'].message_type = _PROTOHOOKFAILURE
_PROTOSPECRESULT.fields_by_name['protoSpec'].message_type = _PROTOSPEC
_PROTOSPECRESULT.fields_by_name['errors'].message_type = _ERROR
_ERROR.fields_by_name['type'].enum_type = _ERROR_ERRORTYPE
_ERROR_ERRORTYPE.containing_type = _ERROR
DESCRIPTOR.message_types_by_name['ProtoSpec'] = _PROTOSPEC
DESCRIPTOR.message_types_by_name['ProtoItem'] = _PROTOITEM
DESCRIPTOR.message_types_by_name['ProtoScenario'] = _PROTOSCENARIO
DESCRIPTOR.message_types_by_name['Span'] = _SPAN
DESCRIPTOR.message_types_by_name['ProtoTableDrivenScenario'] = _PROTOTABLEDRIVENSCENARIO
DESCRIPTOR.message_types_by_name['ProtoStep'] = _PROTOSTEP
DESCRIPTOR.message_types_by_name['ProtoConcept'] = _PROTOCONCEPT
DESCRIPTOR.message_types_by_name['ProtoTags'] = _PROTOTAGS
DESCRIPTOR.message_types_by_name['Fragment'] = _FRAGMENT
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['ProtoComment'] = _PROTOCOMMENT
DESCRIPTOR.message_types_by_name['ProtoTable'] = _PROTOTABLE
DESCRIPTOR.message_types_by_name['ProtoTableRow'] = _PROTOTABLEROW
DESCRIPTOR.message_types_by_name['ProtoStepExecutionResult'] = _PROTOSTEPEXECUTIONRESULT
DESCRIPTOR.message_types_by_name['ProtoExecutionResult'] = _PROTOEXECUTIONRESULT
DESCRIPTOR.message_types_by_name['ProtoHookFailure'] = _PROTOHOOKFAILURE
DESCRIPTOR.message_types_by_name['ProtoSuiteResult'] = _PROTOSUITERESULT
DESCRIPTOR.message_types_by_name['ProtoSpecResult'] = _PROTOSPECRESULT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['ProtoStepValue'] = _PROTOSTEPVALUE
DESCRIPTOR.enum_types_by_name['ExecutionStatus'] = _EXECUTIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoSpec = _reflection.GeneratedProtocolMessageType('ProtoSpec', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSPEC,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoSpec)
  ))
_sym_db.RegisterMessage(ProtoSpec)

ProtoItem = _reflection.GeneratedProtocolMessageType('ProtoItem', (_message.Message,), dict(
  DESCRIPTOR = _PROTOITEM,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoItem)
  ))
_sym_db.RegisterMessage(ProtoItem)

ProtoScenario = _reflection.GeneratedProtocolMessageType('ProtoScenario', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSCENARIO,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoScenario)
  ))
_sym_db.RegisterMessage(ProtoScenario)

Span = _reflection.GeneratedProtocolMessageType('Span', (_message.Message,), dict(
  DESCRIPTOR = _SPAN,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.Span)
  ))
_sym_db.RegisterMessage(Span)

ProtoTableDrivenScenario = _reflection.GeneratedProtocolMessageType('ProtoTableDrivenScenario', (_message.Message,), dict(
  DESCRIPTOR = _PROTOTABLEDRIVENSCENARIO,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoTableDrivenScenario)
  ))
_sym_db.RegisterMessage(ProtoTableDrivenScenario)

ProtoStep = _reflection.GeneratedProtocolMessageType('ProtoStep', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSTEP,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoStep)
  ))
_sym_db.RegisterMessage(ProtoStep)

ProtoConcept = _reflection.GeneratedProtocolMessageType('ProtoConcept', (_message.Message,), dict(
  DESCRIPTOR = _PROTOCONCEPT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoConcept)
  ))
_sym_db.RegisterMessage(ProtoConcept)

ProtoTags = _reflection.GeneratedProtocolMessageType('ProtoTags', (_message.Message,), dict(
  DESCRIPTOR = _PROTOTAGS,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoTags)
  ))
_sym_db.RegisterMessage(ProtoTags)

Fragment = _reflection.GeneratedProtocolMessageType('Fragment', (_message.Message,), dict(
  DESCRIPTOR = _FRAGMENT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.Fragment)
  ))
_sym_db.RegisterMessage(Fragment)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETER,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.Parameter)
  ))
_sym_db.RegisterMessage(Parameter)

ProtoComment = _reflection.GeneratedProtocolMessageType('ProtoComment', (_message.Message,), dict(
  DESCRIPTOR = _PROTOCOMMENT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoComment)
  ))
_sym_db.RegisterMessage(ProtoComment)

ProtoTable = _reflection.GeneratedProtocolMessageType('ProtoTable', (_message.Message,), dict(
  DESCRIPTOR = _PROTOTABLE,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoTable)
  ))
_sym_db.RegisterMessage(ProtoTable)

ProtoTableRow = _reflection.GeneratedProtocolMessageType('ProtoTableRow', (_message.Message,), dict(
  DESCRIPTOR = _PROTOTABLEROW,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoTableRow)
  ))
_sym_db.RegisterMessage(ProtoTableRow)

ProtoStepExecutionResult = _reflection.GeneratedProtocolMessageType('ProtoStepExecutionResult', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSTEPEXECUTIONRESULT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoStepExecutionResult)
  ))
_sym_db.RegisterMessage(ProtoStepExecutionResult)

ProtoExecutionResult = _reflection.GeneratedProtocolMessageType('ProtoExecutionResult', (_message.Message,), dict(
  DESCRIPTOR = _PROTOEXECUTIONRESULT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoExecutionResult)
  ))
_sym_db.RegisterMessage(ProtoExecutionResult)

ProtoHookFailure = _reflection.GeneratedProtocolMessageType('ProtoHookFailure', (_message.Message,), dict(
  DESCRIPTOR = _PROTOHOOKFAILURE,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoHookFailure)
  ))
_sym_db.RegisterMessage(ProtoHookFailure)

ProtoSuiteResult = _reflection.GeneratedProtocolMessageType('ProtoSuiteResult', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSUITERESULT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoSuiteResult)
  ))
_sym_db.RegisterMessage(ProtoSuiteResult)

ProtoSpecResult = _reflection.GeneratedProtocolMessageType('ProtoSpecResult', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSPECRESULT,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoSpecResult)
  ))
_sym_db.RegisterMessage(ProtoSpecResult)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.Error)
  ))
_sym_db.RegisterMessage(Error)

ProtoStepValue = _reflection.GeneratedProtocolMessageType('ProtoStepValue', (_message.Message,), dict(
  DESCRIPTOR = _PROTOSTEPVALUE,
  __module__ = 'spec_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ProtoStepValue)
  ))
_sym_db.RegisterMessage(ProtoStepValue)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\026com.thoughtworks.gauge\252\002\016Gauge.Messages'))
_PROTOSPEC.fields_by_name['preHookMessage'].has_options = True
_PROTOSPEC.fields_by_name['preHookMessage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSPEC.fields_by_name['postHookMessage'].has_options = True
_PROTOSPEC.fields_by_name['postHookMessage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSCENARIO.fields_by_name['failed'].has_options = True
_PROTOSCENARIO.fields_by_name['failed']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSCENARIO.fields_by_name['skipped'].has_options = True
_PROTOSCENARIO.fields_by_name['skipped']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSCENARIO.fields_by_name['preHookMessage'].has_options = True
_PROTOSCENARIO.fields_by_name['preHookMessage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSCENARIO.fields_by_name['postHookMessage'].has_options = True
_PROTOSCENARIO.fields_by_name['postHookMessage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOEXECUTIONRESULT.fields_by_name['screenShot'].has_options = True
_PROTOEXECUTIONRESULT.fields_by_name['screenShot']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOHOOKFAILURE.fields_by_name['screenShot'].has_options = True
_PROTOHOOKFAILURE.fields_by_name['screenShot']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSUITERESULT.fields_by_name['preHookMessage'].has_options = True
_PROTOSUITERESULT.fields_by_name['preHookMessage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_PROTOSUITERESULT.fields_by_name['postHookMessage'].has_options = True
_PROTOSUITERESULT.fields_by_name['postHookMessage']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)



import threading
from getgauge import processor, validator, refactor
from getgauge.messages import lsp_pb2_grpc
from getgauge.messages.lsp_pb2 import Empty
from getgauge.messages.messages_pb2 import Message, \
    ImplementationFileGlobPatternResponse, StepNamesResponse, \
    ImplementationFileListResponse
from getgauge.registry import registry
from getgauge.util import get_impl_files, get_step_impl_dirs


class LspServerHandler(lsp_pb2_grpc.lspServiceServicer):

    def __init__(self, server):
        self.server = server
        self.kill_event = threading.Event()

    def GetStepNames(self, request, context):
        res = StepNamesResponse()
        res.steps.extend(registry.steps())
        return res

    def CacheFile(self, request, context):
        file = request.filePath
        status = request.status
        processor.update_registry(file, status, request.content)
        return Empty()

    def GetStepPositions(self, request, context):
        res = Message()
        processor.step_positions_response(request.filePath, res)
        return res.stepPositionsResponse

    def GetImplementationFiles(self, request, context):
        res = ImplementationFileListResponse()
        res.implementationFilePaths.extend(get_impl_files())
        return res

    def ImplementStub(self, request, context):
        res = Message()
        processor.stub_impl_response(
            request.codes, request.implementationFilePath, res)
        return res.fileDiff

    def ValidateStep(self, request, context):
        res = Message()
        validator.validate_step(request, res)
        return res.stepValidateResponse

    def Refactor(self, request, context, with_location=True):
        res = Message()
        refactor.refactor_step(request, res, with_location)
        return res.refactorResponse

    def GetStepName(self, request, context):
        res = Message()
        info = registry.get_info_for(request.stepValue)
        processor.step_name_response(info, res)
        return res.stepNameResponse

    def GetGlobPatterns(self, request, context):
        res = ImplementationFileGlobPatternResponse()
        globPatterns = [["{}/**/*.py".format(d)] for d in get_step_impl_dirs()]
        res.globPatterns.extend([item for sublist in globPatterns for item in sublist])
        return res

    def KillProcess(self, request, context):
        self.server.stop(0)
        self.kill_event.set()
        return Empty()

    def wait_till_terminated(self):
        self.kill_event.wait()
        exit(0)



import six
from getgauge import logger
from redbaron import RedBaron


class RedbaronPythonFile(object):

    @staticmethod
    def parse(file_path, content=None):
        """
        Create a PythonFile object with specified file_path and content.
        If content is None then, it is loaded from the file_path method.
        Otherwise, file_path is only used for reporting errors.
        """
        try:
            if content is None:
                with open(file_path) as f:
                    content = f.read()
            py_tree = RedBaron(content)
            return RedbaronPythonFile(file_path, py_tree)
        except Exception as ex:
            # Trim parsing error message to only include failure location
            msg = str(ex)
            marker = "<---- here\n"
            marker_pos = msg.find(marker)
            if marker_pos > 0:
                msg = msg[:marker_pos + len(marker)]
            logger.error("Failed to parse {}: {}".format(file_path, msg))

    def __init__(self, file_path, py_tree):
        self.file_path = file_path
        self.py_tree = py_tree

    def _span_for_node(self, node, lazy=False):
        def calculate_span():
            try:
                # For some reason RedBaron does not create absolute_bounding_box
                # attributes for some content passed during unit test so we have
                # to catch AttributeError here and return invalid data
                box = node.absolute_bounding_box
                # Column numbers start at 1 where-as we want to start at 0. Also
                # column 0 is used to indicate end before start of line.
                return {
                    'start': box.top_left.line,
                    'startChar': max(0, box.top_left.column - 1),
                    'end': box.bottom_right.line,
                    'endChar': max(0, box.bottom_right.column),
                }
            except AttributeError:
                return {'start': 0, 'startChar': 0, 'end': 0, 'endChar': 0}

        return calculate_span if lazy else calculate_span()

    def _iter_step_func_decorators(self):
        """Find functions with step decorator in parsed file."""
        for node in self.py_tree.find_all('def'):
            for decorator in node.decorators:
                try:
                    if decorator.name.value == 'step':
                        yield node, decorator
                        break
                except AttributeError:
                    continue

    def _step_decorator_args(self, decorator):
        """
        Get arguments passed to step decorators converted to python objects.
        """
        args = decorator.call.value
        step = None
        if len(args) == 1:
            try:
                step = args[0].value.to_python()
            except (ValueError, SyntaxError):
                pass
            if isinstance(step, six.string_types + (list,)):
                return step
            logger.error("Decorator step accepts either a string or a list of \
                strings - %s".format(self.file_path))
        else:
            logger.error("Decorator step accepts only one argument - %s".format(self.file_path))

    def iter_steps(self):
        """Iterate over steps in the parsed file."""
        for func, decorator in self._iter_step_func_decorators():
            step = self._step_decorator_args(decorator)
            if step:
                yield step, func.name, self._span_for_node(func, True)

    def _find_step_node(self, step_text):
        """Find the ast node which contains the text."""
        for func, decorator in self._iter_step_func_decorators():
            step = self._step_decorator_args(decorator)
            arg_node = decorator.call.value[0].value
            if step == step_text:
                return arg_node, func
            elif isinstance(step, list) and step_text in step:
                step_node = arg_node[step.index(step_text)]
                return step_node, func
        return None, None

    def _refactor_step_text(self, step, old_text, new_text):
        step_span = self._span_for_node(step, False)
        step.value = step.value.replace(old_text, new_text)
        return step_span, step.value

    def _get_param_name(self, param_nodes, i):
        name = 'arg{}'.format(i)
        if name not in [x.name.value for x in param_nodes]:
            return name
        return self._get_param_name(param_nodes, i + 1)

    def _move_params(self, params, move_param_from_idx):
        # If the move list is exactly same as current params
        # list then no need to create a new list.
        if list(range(len(params))) == move_param_from_idx:
            return params
        new_params = []
        for (new_idx, old_idx) in enumerate(move_param_from_idx):
            if old_idx < 0:
                new_params.append(self._get_param_name(params, new_idx))
            else:
                new_params.append(params[old_idx].name.value)
        return ', '.join(new_params)

    def refactor_step(self, old_text, new_text, move_param_from_idx):
        """
        Find the step with old_text and change it to new_text.
        The step function parameters are also changed according
        to move_param_from_idx.  Each entry in this list should
        specify parameter position from old
        """
        diffs = []
        step, func = self._find_step_node(old_text)
        if step is None:
            return diffs
        step_diff = self._refactor_step_text(step, old_text, new_text)
        diffs.append(step_diff)
        moved_params = self._move_params(func.arguments, move_param_from_idx)
        if func.arguments is not moved_params:
            params_span = self._span_for_node(func.arguments, False)
            func.arguments = moved_params
            diffs.append((params_span, func.arguments.dumps()))
        return diffs

    def get_code(self):
        """Return current content of the tree."""
        return self.py_tree.dumps()
